import { reactive, ref } from "vue"
import request from "@/utils/request"
import { showDanger } from "@/utils"

export default () => {
  const loading = ref(false)
  const list = ref([])
  const page = reactive({})
  const detail = reactive({})
  const rentRole = reactive({})
  const rentKeyBox = reactive({})
  const getList = (data) => {
    loading.value = true
    request({
      loadingId: "renting.list",
      url: "/rent/list",
      data: {
        pageNo: 1,
        pageSize: 10,
        ...data,
      },
    })
      .then((res) => {
        const { pageNo, pageSize, endRow, result } = res || {}
        Object.assign(page, {
          pageNo,
          pageSize,
          endRow,
        })
        list.value = pageNo <= 1 ? result : list.value.concat(list.value)
        loading.value = false
      })
      .catch((e) => {
        console.error(e)
        loading.value = false
      })
  }

  const getDetail = (data) => {
    // loading.value = true
    request({
      loadingId: "rent.view",
      url: "/rent/view",
      params: {
        id: data,
      },
    })
      .then((res) => {
        console.log(res, "res")

        Object.assign(detail, res)
      })
      .catch((e) => {
        console.error(e)
        // loading.value = false
        showDanger("获取详情失败")
      })
  }

  // 角色人信息
  const getRole = (data) => {
    request({
      loadingId: "rent.role.view",
      url: "/rent/role/view",
      params: {
        roomId: data,
      },
    })
      .then((res) => {
        Object.assign(rentRole, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger("获取角色人失败")
      })
  }

  // 钥匙信息
  const getKey = (data) => {
    request({
      loadingId: "rent.key.view",
      url: "/rent/key/view",
      params: {
        roomId: data,
      },
    })
      .then((res) => {
        Object.assign(rentKeyBox, res)
      })
      .catch((e) => {
        console.error(e)
        showDanger("获取钥匙失败")
      })
  }

  return {
    list,
    page,
    getList,
    detail,
    getDetail,
    loading,
    getRole,
    rentRole,
    getKey,
    rentKeyBox,
  }
}
